@@ -13,6 +13,7 @@ import sys
 from types import FrameType
 from typing import ClassVar, IO, Optional, Tuple, TypeVar
 
+import dateutil.tz
 from zstandard import ZstdCompressor, ZstdCompressionWriter
 
 from clp_logging.encoder import CLPEncoder
@@ -34,13 +35,17 @@ def _init_timeinfo(fmt: Optional[str], tz: Optional[str]) -> Tuple[str, str]:
     readers.)
     :param fmt: Timestamp format written in preamble to be used when generating
     the logs with a reader.
-    :param tz: Timezone written in preamble to be used when generating the
-    timestamp from Unix epoch time.
+    :param tz: Timezone in TZID format written in preamble to be used when
+    generating the timestamp from Unix epoch time.
     """
     if not fmt:
         fmt = "yyyy-MM-d H:m:s.A"
     if not tz:
-        tz = datetime.now().astimezone().strftime("%z")
+        tzf = dateutil.tz.gettz()
+        if tzf:
+            if tzf._filename == "/etc/localtime":
+                tzp = Path.resolve(Path(tzf._filename))
+            tz = "/".join([tzp.parent.name, tzp.name])
     return fmt, tz
 
 
@@ -163,7 +168,7 @@ class CLPSockListener:
                 view: memoryview = memoryview(buf)
                 i: int = 0
                 while i < size:
-                    read = conn.recv_into(view[i:], size)
+                    read = conn.recv_into(view[i:], size - i)
                     if read == 0:
                         raise OSError("handler conn.recv_into returned 0 before finishing")
                     i += read
@@ -350,12 +355,12 @@ class CLPSockHandler(CLPBaseHandler):
         never returning and not closing properly on signal/EOF_CHAR
         """
         super().__init__()
-        sock_path: Path = log_path.with_suffix(".sock")
+        self.sock_path: Path = log_path.with_suffix(".sock")
         self.closed: bool = False
         self.sock: socket.socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
         self.listener_pid: int = 0
 
-        if self.sock.connect_ex(str(sock_path)) != 0:
+        if self.sock.connect_ex(str(self.sock_path)) != 0:
             if create_listener:
                 self.listener_pid = CLPSockListener.fork(
                     log_path, timestamp_format, timezone, timeout
@@ -364,7 +369,7 @@ class CLPSockHandler(CLPBaseHandler):
             # If we fail to connect again, the listener failed to resolve any
             # issues, so we raise an exception as there is nothing new to try
             try:
-                self.sock.connect(str(sock_path))
+                self.sock.connect(str(self.sock_path))
             except OSError:
                 self.sock.close()
                 raise
@@ -411,7 +416,13 @@ class CLPSockHandler(CLPBaseHandler):
         self.closed = True
 
     def stop_listener(self) -> None:
-        self.sock.send((0).to_bytes(SIZEOF_INT, BYTE_ORDER))
+        try:
+            self.sock.send((0).to_bytes(SIZEOF_INT, BYTE_ORDER))
+        except:
+            sock: socket.socket = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+            sock.connect(str(self.sock_path))
+            sock.send((0).to_bytes(SIZEOF_INT, BYTE_ORDER))
+            sock.close()
         self.close()
 
 
